Please join a research study to help us test new approaches to learning programming!
====================================================================================

Hi! We are a team of researchers in Professor Ericson’s Lab at UMSI!

.. raw:: html

    <h4>The Project</h4>
    <p>You are invited to participate in a research study about how Parsons problems (a type of coding puzzle) may help
    CS entry-level learning. You must be at least <b>18</b> to participate. <br> 
    Your participation will help more students become successful in computing courses in a low-cost, scalable, and easily
    adopted way. <br> </p>

    <h4> What Will Occur </h4>
    <p>This study takes 60 minutes to one hour to finish. The study materials include:</p>
    <ul>
        <li>Knowledge Introduction - A basic knowledge introduction about Python <b>Class</b> (~5 mins)</li>
        <li>System Introduction - Materials to get you familiar with the types of problems in this study (~5 mins)</li>
        <li>Pre Survey - Questions about your level of programming self-efficacy (~5 mins)</li>
        <li>Practice - Five code practice problems (~30 mins)</li>
        <li>Posttest - A short posttest consists of 5 programming questions (~15 mins)</li>
    </ul>
    <p>Each section must be completed in order. After finishing one part, you can click the link provided under <b>"What to do next"</b> to the next part.</p>

    <h4> Confidentiality of Information </h4>
    <p>All the data we collect will be de-identified. We will not collect any identifiable data such as demographic information. </p>

    <h4>Who to Contact</h4>
    <p> If you have any questions about the study, please contact Xinying Hou at xyhou@umich.edu
    with “[Parsons Problem Study]” included in the email subject. <br></p>

    <p>We greatly appreciate your help!</p>
.. note::
    .. raw:: html

        <h4>Click on the following link 👉 <b><a href="intro-cls.html">Basic Knowledge Introduction</a></b> 👈 to start!</h4>
        
    